@@ -8,7 +8,7 @@ supports .tiddler, .tid, .js and .recipe files
 
 import os
 
-from urllib2 import urlopen, unquote, URLError, HTTPError
+from urllib2 import urlopen, quote, unquote, URLError, HTTPError
 
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.serializer import Serializer
@@ -122,6 +122,10 @@ def _expand_recipe(uri): # XXX: adapted from devstore
 	uris = []
 	for rule in rules:
 		type, uri = rule.split(": ")
+		if not (uri.startswith("http:") or uri.startswith("https:")):
+			if not "%" in uri:
+				uri = quote(uri)
+
 		uri = os.path.join(base_dir, uri)
 		if type == "recipe":
 			uris = uris + _expand_recipe(uri)
